        function getT(rr,cc){
       if(rr==2 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==2 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 13 <br>1,3,7,10,12,22,24,35,39,41,43,44,45';}
       if(rr==2 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>47</strong> miembros: 11 <strong>control</strong><br>0,5,9,13,16,21,29,30,32,47,49';}
       if(rr==2 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 9 <br>11,15,17,20,23,25,34,38,46';}
       if(rr==2 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>33</strong> miembros: 8 <br>2,18,19,27,31,33,40,50';}
       if(rr==2 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 5 <br>4,6,36,37,48';}
       if(rr==2 && cc==6){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 5 <br>8,14,26,28,42';}
       if(rr==9 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==9 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 13 <br>1,3,7,10,12,22,24,35,39,41,43,44,45';}
       if(rr==9 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>47</strong> miembros: 11 <strong>control</strong><br>0,5,9,13,16,21,29,30,32,47,49';}
       if(rr==9 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 9 <br>11,15,17,20,23,25,34,38,46';}
       if(rr==9 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>33</strong> miembros: 8 <br>2,18,19,27,31,33,40,50';}
       if(rr==9 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 5 <br>4,6,36,37,48';}
       if(rr==9 && cc==6){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 5 <br>8,14,26,28,42';}
       if(rr==10 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==10 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 13 <br>1,3,7,10,12,22,24,35,39,41,43,44,45';}
       if(rr==10 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>47</strong> miembros: 11 <strong>control</strong><br>0,5,9,13,16,21,29,30,32,47,49';}
       if(rr==10 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 9 <br>11,15,17,20,23,25,34,38,46';}
       if(rr==10 && cc==4){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>33</strong> miembros: 8 <br>2,18,19,27,31,33,40,50';}
       if(rr==10 && cc==5){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 5 <br>4,6,36,37,48';}
       if(rr==10 && cc==6){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 5 <br>8,14,26,28,42';}
       if(rr==11 && cc==0){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==11 && cc==1){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 13 <br>1,3,7,10,12,22,24,35,39,41,43,44,45';}
       if(rr==11 && cc==2){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>47</strong> miembros: 11 <strong>control</strong><br>0,5,9,13,16,21,29,30,32,47,49';}
       if(rr==11 && cc==3){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 9 <br>11,15,17,20,23,25,34,38,46';}
       if(rr==11 && cc==4){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>33</strong> miembros: 8 <br>2,18,19,27,31,33,40,50';}
       if(rr==11 && cc==5){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 5 <br>4,6,36,37,48';}
       if(rr==11 && cc==6){return '<strong>Temperatura a 2m (C)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 5 <br>8,14,26,28,42';}
       if(rr==12 && cc==0){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==12 && cc==1){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 13 <br>1,3,7,10,12,22,24,35,39,41,43,44,45';}
       if(rr==12 && cc==2){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>47</strong> miembros: 11 <strong>control</strong><br>0,5,9,13,16,21,29,30,32,47,49';}
       if(rr==12 && cc==3){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 9 <br>11,15,17,20,23,25,34,38,46';}
       if(rr==12 && cc==4){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>33</strong> miembros: 8 <br>2,18,19,27,31,33,40,50';}
       if(rr==12 && cc==5){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 5 <br>4,6,36,37,48';}
       if(rr==12 && cc==6){return '<strong>Racha maxima de viento a 10m en 6 horas anteriores (nudos)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 5 <br>8,14,26,28,42';}
       if(rr==13 && cc==0){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==13 && cc==1){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 13 <br>1,3,7,10,12,22,24,35,39,41,43,44,45';}
       if(rr==13 && cc==2){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>47</strong> miembros: 11 <strong>control</strong><br>0,5,9,13,16,21,29,30,32,47,49';}
       if(rr==13 && cc==3){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 9 <br>11,15,17,20,23,25,34,38,46';}
       if(rr==13 && cc==4){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>33</strong> miembros: 8 <br>2,18,19,27,31,33,40,50';}
       if(rr==13 && cc==5){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 5 <br>4,6,36,37,48';}
       if(rr==13 && cc==6){return '<strong>MUCAPE (J/Kg)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 5 <br>8,14,26,28,42';}
       if(rr==14 && cc==0){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==14 && cc==1){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 13 <br>1,3,7,10,12,22,24,35,39,41,43,44,45';}
       if(rr==14 && cc==2){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>47</strong> miembros: 11 <strong>control</strong><br>0,5,9,13,16,21,29,30,32,47,49';}
       if(rr==14 && cc==3){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 9 <br>11,15,17,20,23,25,34,38,46';}
       if(rr==14 && cc==4){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>33</strong> miembros: 8 <br>2,18,19,27,31,33,40,50';}
       if(rr==14 && cc==5){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 5 <br>4,6,36,37,48';}
       if(rr==14 && cc==6){return '<strong>Precipitacion de 00 a 24 UTC (mm)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 5 <br>8,14,26,28,42';}
       if(rr==15 && cc==0){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==15 && cc==1){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 13 <br>1,3,7,10,12,22,24,35,39,41,43,44,45';}
       if(rr==15 && cc==2){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>47</strong> miembros: 11 <strong>control</strong><br>0,5,9,13,16,21,29,30,32,47,49';}
       if(rr==15 && cc==3){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 9 <br>11,15,17,20,23,25,34,38,46';}
       if(rr==15 && cc==4){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>33</strong> miembros: 8 <br>2,18,19,27,31,33,40,50';}
       if(rr==15 && cc==5){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 5 <br>4,6,36,37,48';}
       if(rr==15 && cc==6){return '<strong>Nieve acumulada de 00 a 24 UTC (mm de agua equivalente)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 5 <br>8,14,26,28,42';}
       if(rr==16 && cc==0){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br><strong>control +<br>EPS</strong>';}
       if(rr==16 && cc==1){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>1</strong> representante: <strong>3</strong> miembros: 13 <br>1,3,7,10,12,22,24,35,39,41,43,44,45';}
       if(rr==16 && cc==2){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>2</strong> representante: <strong>47</strong> miembros: 11 <strong>control</strong><br>0,5,9,13,16,21,29,30,32,47,49';}
       if(rr==16 && cc==3){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>3</strong> representante: <strong>23</strong> miembros: 9 <br>11,15,17,20,23,25,34,38,46';}
       if(rr==16 && cc==4){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>4</strong> representante: <strong>33</strong> miembros: 8 <br>2,18,19,27,31,33,40,50';}
       if(rr==16 && cc==5){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>5</strong> representante: <strong>36</strong> miembros: 5 <br>4,6,36,37,48';}
       if(rr==16 && cc==6){return '<strong>Viento a 10 m (m/s)</strong><br><br><strong>20260426 a 00</strong> UTC HH+228 (rango:216-240)<br>grupo: <strong>6</strong> representante: <strong>8</strong> miembros: 5 <br>8,14,26,28,42';}
}
